@@ -3,7 +3,7 @@ import sys
 
 from pathlib import Path
 from slai_cli import log
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 from slai_cli.profile.configure import get_credentials
 from slai.modules.runtime import detect_credentials, detect_runtime
 from slai.exceptions import NoCredentialsFound
